@@ -6,9 +6,9 @@
  * Handles attachment downloads to the users computer.
  * Also allows displaying of attachments when possible.
  *
- * @copyright &copy; 1999-2007 The SquirrelMail Project Team
+ * @copyright &copy; 1999-2009 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: download.php 12537 2007-07-14 18:34:04Z kink $
+ * @version $Id: download.php 13549 2009-04-15 22:00:49Z jervfors $
  * @package squirrelmail
  */
 
@@ -51,10 +51,16 @@ global $uid_support;
 $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 $mbx_response =  sqimap_mailbox_select($imapConnection, $mailbox);
 
-$message = $messages[$mbx_response['UIDVALIDITY']]["$passed_id"];
+$message = '';
+
+if (isset($messages[$mbx_response['UIDVALIDITY']]["$passed_id"])) {
+    $message = $messages[$mbx_response['UIDVALIDITY']]["$passed_id"];
+}
+
 if (!is_object($message)) {
     $message = sqimap_get_message($imapConnection,$passed_id, $mailbox);
 }
+
 $subject = $message->rfc822_header->subject;
 if ($ent_id) {
     $message = $message->getEntity($ent_id);
@@ -72,7 +78,7 @@ if ($ent_id) {
     /* raw message */
     $type0 = 'message';
     $type1 = 'rfc822';
-    $encoding = 'US-ASCII';
+    $encoding = '7bit';
     $header = $message->header;
 }
 
