@@ -5,9 +5,9 @@
  *
  * Derived from webmail.php by Ralf Kraudelt <kraude@wiwi.uni-rostock.de>
  *
- * @copyright &copy; 1999-2007 The SquirrelMail Project Team
+ * @copyright &copy; 1999-2009 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: redirect.php 12848 2008-01-04 07:18:01Z pdontthink $
+ * @version $Id: redirect.php 13676 2009-05-11 22:48:03Z pdontthink $
  * @package squirrelmail
  */
 
@@ -24,19 +24,15 @@ define('SM_PATH','../');
 require_once(SM_PATH . 'functions/global.php');
 require_once(SM_PATH . 'functions/i18n.php');
 require_once(SM_PATH . 'functions/strings.php');
-require_once(SM_PATH . 'config/config.php');
 require_once(SM_PATH . 'functions/prefs.php');
 require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'functions/plugin.php');
 require_once(SM_PATH . 'functions/constants.php');
 require_once(SM_PATH . 'functions/page_header.php');
 
-$base_uri = sqm_baseuri();
-
 header('Pragma: no-cache');
 $location = get_location();
 
-session_set_cookie_params (0, $base_uri);
 sqsession_is_active();
 
 sqsession_unregister ('user_is_logged_in');
@@ -59,8 +55,7 @@ if (!sqgetGlobalVar('mailtodata', $mailtodata)) {
 
 set_up_language($squirrelmail_language, true);
 /* Refresh the language cookie. */
-setcookie('squirrelmail_language', $squirrelmail_language, time()+2592000,
-          $base_uri);
+sqsetcookie('squirrelmail_language', $squirrelmail_language, time()+2592000, $base_uri);
 
 if (!isset($login_username)) {
     include_once(SM_PATH .  'functions/display_messages.php' );
@@ -71,6 +66,22 @@ if (!isset($login_username)) {
 if (!sqsession_is_registered('user_is_logged_in')) {
     do_hook ('login_before');
 
+    /**
+     * Regenerate session id to make sure that authenticated session uses
+     * different ID than one used before user authenticated.  This is a
+     * countermeasure against session fixation attacks.
+     * NB: session_regenerate_id() was added in PHP 4.3.2 (and new session
+     *     cookie is only sent out in this call as of PHP 4.3.3), but PHP 4
+     *     is not vulnerable to session fixation problems in SquirrelMail
+     *     because it prioritizes $base_uri subdirectory cookies differently
+     *     than PHP 5, which is otherwise vulnerable.  If we really want to,
+     *     we could define our own session_regenerate_id() when one does not
+     *     exist, but there seems to be no reason to do so.
+     */
+    if (function_exists('session_regenerate_id')) {
+        session_regenerate_id();
+    }
+
     $onetimepad = OneTimePadCreate(strlen($secretkey));
     $key = OneTimePadEncrypt($secretkey, $onetimepad);
     sqsession_register($onetimepad, 'onetimepad');
@@ -94,7 +105,7 @@ if (!sqsession_is_registered('user_is_logged_in')) {
 
     $username = $login_username;
     sqsession_register ($username, 'username');
-    setcookie('key', $key, 0, $base_uri);
+    sqsetcookie('key', $key, 0, $base_uri);
     do_hook ('login_verified');
 
 }
